@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20190419';
+our $VERSION = '5.20190420';
 our %utilities;
 
 sub utilities {
@@ -1487,6 +1487,13 @@ my %delta = (
         removed => {
         }
     },
+    5.029010 => {
+        delta_from => 5.029009,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
